#ifndef _CAMKEY_H_
#define _CAMKEY_H_

#include <glib.h>
#include <dbus/dbus-glib-lowlevel.h>
#include <dbus/dbus-glib.h>
#include <libhal.h>
#include <string.h>
#include <X11/Xlib.h>
#include <X11/extensions/XTest.h>

class CameraKey
{
	public:
	CameraKey();
	~CameraKey();
	bool Init();
	DBusConnection* GetSysDBus();

	private:

	static void PropertyModified( LibHalContext* ctx, const char* udi, const char* key,
                            dbus_bool_t is_removed, dbus_bool_t is_added);

	static void SendCtrlBackspace();

	//GMainLoop* g_loop;
	//DBusConnection* dbus_sess;
	DBusConnection* dbus_sys;
	DBusMessage* msg_dashboard;
	bool initSuccess;

	static DBusError dbus_err;
	static LibHalContext* halctx;
	static int shutter_state;
	static Display* dpy;
};


#endif
